import {useState} from "react";
import styled from 'styled-components';
import {DropzoneArea} from 'material-ui-dropzone';
import {applyDrag, uploadFile} from "../shared/services&utilits/utilits";
import {gqlSendPost} from "../shared/services&utilits/gqlRequest";
import {
    setActiveUserAllPosts,
    setActiveUserAllPostsAsync
} from "../store/actionCreators/ActionCreators";
import {connect} from "react-redux";
import DeleteForeverSharpIcon from '@mui/icons-material/DeleteForeverSharp';
import {Container, Draggable} from 'react-smooth-dnd';
import {SendButton, Title} from "../shared/styledComponents";

const NewPostWrapper = styled.div`
  width: 50vw;
  height: 70vh;
  display: flex;
  flex-direction: column;
  justify-content: space-around;
  align-items: center;
`
const DropZOne = styled.div`
  width: 80%;
`

const TitleInput = styled.input`
  margin-left: 20px;
  width: 300px;
`

const CancelButton = styled(SendButton)`
`
const TextArea = styled.textarea`
  resize: none;
  width: 80%;
  height: 20%;
`
const Preview = styled.div`
  display: flex;
`
const PreviewImg = styled.img`
  width: 120px;
  height: 80px;
`

const ImageWrapper = styled.div`
  position: relative;
  width: 120px;
  height: 80px;
  margin: 5px;
`

function NewPost({closeModal, postData, loadedImages, setActiveUserAllPosts}) {

    const [title, setTitle] = useState((postData && postData.title) || "");
    const [description, setDescription] = useState((postData && postData.text) || "");
    const [previewImages, setPreviewImages] = useState(loadedImages || []);

    const sendHandler = async () => {
        const responce = await gqlSendPost({
            _id: (postData && postData._id) || "",
            title: title,
            text: description,
            images: previewImages,
        })

        if (responce.ok) {
            cancelHandler();
            setActiveUserAllPosts(null)
        }
    }
    const cancelHandler = () => {
        setTitle("")
        setDescription("")
        closeModal()
    }

    const deleteImage = (e, index) => {
        const filteredPreviewImages = previewImages.filter((img, i) => index !== i);
        setPreviewImages(filteredPreviewImages);
    }


    const getPreviewImages = () => {
        return previewImages.map((img, index) => {
            return <Draggable key={index}>
                <div className="draggable-item-horizontal">
                    <ImageWrapper>
                        <PreviewImg src={img.url}/>
                        <DeleteForeverSharpIcon style={{color: "red", position: "absolute", top: "1px", right: "1px"}}
                                                onClick={(e) => deleteImage(e, index)}/>
                    </ImageWrapper>
                </div>
            </Draggable>
        })
    }

    const loadFIle = async (file, newPreviewPicures) => {
        const img = await uploadFile(file);
        newPreviewPicures.push(img)
        setPreviewImages([...previewImages, ...newPreviewPicures])
    }

    const saveFiles = async (files) => {
        const newPreviewPicures = [];
        await files.forEach((file => {
            loadFIle(file, newPreviewPicures)
        }))

    }

    return (
        <NewPostWrapper>
            <DropZOne>
                <DropzoneArea
                    key={previewImages.length}
                    showPreviews={false}
                    acceptedFiles={['image/*']}
                    dropzoneText={"Drag and drop an image here or click"}
                    onChange={(files) => saveFiles(files)}
                    showPreviewsInDropzone={false}
                />
                <Preview>
                    <Container groupName="1" orientation="horizontal"
                               getChildPayload={i => previewImages[i]}
                               onDrop={e => setPreviewImages(applyDrag(previewImages, e))}
                    >
                        {getPreviewImages()}
                    </Container>

                </Preview>
            </DropZOne>

            <Title> Title:
                <TitleInput type={"text"} value={title} onChange={(e) => {
                    setTitle(e.target.value)
                }}/>
            </Title>

            Text:
            <TextArea value={description} onChange={(e) => {
                setDescription(e.target.value)
            }} cols="30" rows="10"/>

            <div>
                <SendButton onClick={sendHandler}>Send</SendButton>
                <CancelButton onClick={cancelHandler}>Cancel</CancelButton>
            </div>
        </NewPostWrapper>
    )

}

const mapStateToProps = (state) => {
    return {
        id: state.auth.user.sub.id,
    }
}
const mapDispatchToProps = (dispatch) => {
    return {

        setActiveUserAllPostsAsync: (id) => dispatch(setActiveUserAllPostsAsync(id)),
        setActiveUserAllPosts: (id) => dispatch(setActiveUserAllPosts(id)),
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(NewPost);