import {useEffect, useState} from "react";
import picture from "../assets/img/brokenPicture.png";
import AutoAwesomeMotionIcon from "@mui/icons-material/AutoAwesomeMotion";
import ModalWindow from "./ModalWindow";
import styled from "styled-components";
import {gqlOnePost} from "../shared/services&utilits/gqlRequest";
import Post from "./Post";


const PostWrapper = styled.div`
  position: relative;
  display: flex;
  min-width: 300px;
  max-width: 300px;
  margin: 15px;
  box-shadow: rgba(0, 0, 0, 0.25) 0px 0.0625em 0.0625em, rgba(0, 0, 0, 0.25) 0px 0.125em 0.5em, rgba(255, 255, 255, 0.1) 0px 0px 0px 1px inset;
  cursor: pointer;
`
const LogoManyImg = styled.div`
  position: absolute;
  z-index: 2;
  right: 0;
  width: 25px;
  height: 35px;
  transform: scaleX(-1);
`

const InnerModalWrapper = styled.div`
  width: 60vw;
  height: 80vh;
  display: flex;
`


function PostPreview({postId}) {
    const [isModal, setModal] = useState(false);
    const [postData, setPostData] = useState(null);

    useEffect(() => {
        if (!postData) {
            gqlOnePost(postId).then(res => res.json())
                .then(data => setPostData(data["data"].PostFindOne))
        }
    }, [])

    function updatePostData() {
        gqlOnePost(postId).then(res => res.json())
            .then(data => setPostData(data["data"].PostFindOne))
    }

    function toggleModalWindow() {
        setModal(!isModal)
    }

    return (
        <>
            {postData &&
            <PostWrapper onClick={() => toggleModalWindow()}>
                <img src={postData.images ? postData.images[0]?.url : picture} alt="post" style={{width: "100%"}}/>
                {
                    postData.images?.length > 1 && <LogoManyImg>
                        <AutoAwesomeMotionIcon/>
                    </LogoManyImg>
                }
                {isModal &&
                <ModalWindow closeModal={toggleModalWindow}>
                    <InnerModalWrapper>
                        <Post postData={postData} closeModal={toggleModalWindow} updatePostData={updatePostData}/>
                    </InnerModalWrapper>
                </ModalWindow>
                }
            </PostWrapper>
            }
        </>
    )
}

export default PostPreview;