const getGQL = (url) => (query, variables) => {
    return fetch(url, {
        method: "POST",
        // mode: 'no-cors',
        headers: {
            "Content-Type": "application/json",
            ...(localStorage.authToken
                ? {Authorization: "Bearer " + localStorage.authToken}
                : {}),
            'Access-Control-Allow-Origin': "*"
        },
        body: JSON.stringify({query, variables}),
    })
        .then((res) => {
            return res;
        })
}

// const backendURL = 'http://hipstagram.asmer.fs.a-level.com.ua'
// const backendURL = 'http://hipstagram.node.ed.asmer.org.ua'

export const gql = getGQL("/graphql");


export const gqlRegistration = (login, password) => gql(`mutation register($login: String!, $password: String!){
                createUser(login: $login, password: $password) {
                    _id login
                }
            }`, {login: String(login), password: String(password)}
)

export const gqlAboutUser = (_id) => gql(`query AboutMe($userId:String){
            UserFindOne(query:$userId)
            {
              _id createdAt login nick avatar{_id url} 
              followers{_id login nick avatar{_id url}} 
              following{_id login nick avatar{_id url}}
            }
          }`,
    {
        userId: JSON.stringify([{_id}]),
    },
)

export const gqlLogin = (login, password) => gql(
    `query login($login: String!, $password: String!){
        login(login: $login, password: $password)
        }`,
    {login: String(login), password: String(password)}
)

export const gqlAllPosts = (userId) => gql(
    `query allPosts($userId:String!){
  PostFind(query:$userId){
           owner{_id} _id title text images{_id url} createdAt
    }
}`,
    {
        userId: JSON.stringify([
            {___owner: userId},
            {
                sort: [{_id: -1}],
                skip: [0],
                limit: [100],
            },
        ]),
    },
)

export const gqlOnePost = (_id) => gql(
    `query OneFind($post:String){
        PostFindOne(query:$post){
       _id title text images{_id url}
       owner{_id login avatar{_id url}}
       createdAt
       comments{
         _id, createdAt, text  owner{_id login avatar{_id url}}
         answers{
           _id, createdAt, text owner{_id login  avatar{_id url}}
          
         }
       owner{_id login avatar{_id url}}}
       likes{
         _id
         owner{				
            _id login avatar {_id url}
           }
     }
       
 }
     }

      `,
    {
        post: JSON.stringify([{_id}]),
    },
)

export const gqlAddLike = (postId) => gql(
    `mutation AddLike($like:LikeInput){
          LikeUpsert(like:$like)
          {
            _id
          }
        }`,
    {
        like: {
            post: {
                _id: postId,
            },
        },
    },
)


export const gqlDeleteLike = (likeId, postId) => gql(
    `mutation DeleteLike($like:LikeInput){
          LikeDelete(like: $like)
          {
            _id
          }
        }`,
    {
        like: {
            _id: likeId,
            post: {
                _id: postId,
            },
        },
    },
)
export const gqlSendComment = (postId, text) => gql(
    `mutation AddComment($comment:CommentInput){
          CommentUpsert(comment:$comment)
          {
            _id
            text 
            createdAt
          }
        }`,
    {
        comment: {
            post: {
                _id: postId,
            },
            text
        },
    },
)
export const gqlPostsFeed = (skip) => gql(` query allPosts($id:String!){
                PostFind(query:$id){
                    _id   images{url _id originalFileName}
                }
            }`, {
    id: JSON.stringify([{}, {
        sort: [{_id: -1}],
        skip: [skip || 0],
        limit: [10]
    }])
})


export const gqlSubscribe = (my_Id, followId, oldFollowing) =>
    gql(
        `mutation subscribe($user:UserInput) {
        UserUpsert(user: $user) {
          _id following{_id login}
          followers{
            _id login
          }
        }
      }
      `,
        {
            user: {
                _id: my_Id,
                following: [...(oldFollowing || []), {_id: followId}],
            },
        },
    )

export const gqlUnSubscribe = (my_Id, oldFollowing) =>
    gql(
        `mutation unSubscribe($user:UserInput) {
        UserUpsert(user: $user) {
          _id following{_id login}
          followers{
            _id login
          }
        }
      }
      `,
        {
            user: {
                _id: my_Id,
                following: oldFollowing || [],
            },
        },
    )

export const gqlGetUserFollowers = (_id) =>
    gql(` query followers($id:String!){
        UserFindOne(query: $id){
                            followers {_id nick login}
        }
    }`, {id: JSON.stringify([{_id}])})

export const gqlSendPost = (post, postId) =>
    gql(`mutation PostUpsert($post:PostInput){
  PostUpsert(post:$post){
    _id title text images{_id url}
  }
}`,
        {
            post: {
                ...post,
                _id: postId,
                images: post.images.map(({_id}) => ({_id})),
            },
        },
    )
export const gqlSetAvatar = (imageId, _id) =>
    gql(
        `mutation setAvatar($imageId:ID, $userId:String){
    UserUpsert(user:{_id: $userId, avatar: {_id: $imageId}}){
    _id, avatar{
        _id
    }
    }
    }`,
        {imageId, userId: _id},
    )

export const gqlGetFollowings = (_id) => gql(
    `query AllFollowing($userId:String){
  UserFindOne(query:$userId)
    {_id
          following{_id login}
    }
}`,
    {
        userId: JSON.stringify([{_id}]),
    },
)